;; Generated package description from pyim-basedict.el  -*- no-byte-compile: t -*-
(define-package "pyim-basedict" "0.5.5.0.20240923.73912" "The default pinyin dict of pyim" '((pyim "3.7")) :commit "55d9b324831b0fc79ff62f1c6f21aad72341a114" :authors '(("Feng Shu" . "tumashu@163.com")) :maintainer '("Feng Shu" . "tumashu@163.com") :keywords '("convenience" "chinese" "pinyin" "input-method" "complete") :url "https://github.com/tumashu/pyim-basedict")
